import numpy as np
from tools import makeCSVFile

class simHits:
  
  def __init__(self, clusters, bins, csv_path, event):
    self.clusters = clusters
    self.bins = bins
    self.nclusters = len(clusters)
    self.cluster_cell_content, self.cluster_cell_x, self.cluster_cell_y = [], [], []
    self.total_content = []
    self.cell_fractions = []
    self.csv_path = csv_path
    self.event = event

    self.makeHits()
    self.dictionary()

  def makeHits(self):
    for cluster in range(self.nclusters):
        content, xedges, yedges = np.histogram2d(self.clusters[cluster][0], self.clusters[cluster][1], bins=self.bins)
        self.cluster_cell_content.append(content)
        self.cluster_cell_x.append([0.5*(xedges[i] + xedges[i-1]) for i in range(1, len(xedges))])
        self.cluster_cell_y.append([0.5*(yedges[i] + yedges[i-1]) for i in range(1, len(yedges))])

    total_content = [] # total content in each bin
    for x_bin in range(0, len(self.bins)-1):
        total_content_x = []
        for y_bin in range(0, len(self.bins)-1):
            total_bin_content = 0
            for cl in range(0, self.nclusters):
                total_bin_content += self.cluster_cell_content[cl][x_bin][y_bin]
            if total_bin_content == 0: denom = float('inf') # to avoid division by zero
            else: denom = total_bin_content
            total_content_x.append(denom)
        total_content.append(total_content_x)
    
    for cl in range(0, self.nclusters):
        fractions = []
        for x_bin in range(0, len(self.bins)-1):
            fractions_x = []
            for y_bin in range(0, len(self.bins)-1):
                fractions_x.append(self.cluster_cell_content[cl][x_bin][y_bin]/total_content[x_bin][y_bin])
            fractions.append(fractions_x)
        self.cell_fractions.append(fractions)
      

  def getHits(self):
    return self.cluster_cell_x, self.cluster_cell_y, self.cell_fractions, self.cluster_cell_content
  
  def dictionary(self):
    hits_x, hits_y, hits_energy, hits_clusterIndex, hits_detid, hits_fractions = [], [], [], [], [], []
    for cl in range(self.nclusters):
      for hit_x in range(len(self.cluster_cell_x[cl])):
        for hit_y in range(len(self.cluster_cell_y[cl])):
          hits_x.append(self.cluster_cell_x[cl][hit_x])
          hits_y.append(self.cluster_cell_y[cl][hit_y])
          hits_energy.append(self.cluster_cell_content[cl][hit_x][hit_y])
          hits_fractions.append(self.cell_fractions[cl][hit_x][hit_y])
          hits_detid.append(hit_x + hit_y * len(self.cluster_cell_x[cl]))
          if self.cluster_cell_content[cl][hit_x][hit_y] == 0:
            hits_clusterIndex.append(-1) 
          else:
            hits_clusterIndex.append(cl)

    dictionary = {'simHit_x': hits_x,
                  'simHit_y': hits_y,
                  'simHit_z': [0 for _ in range(len(hits_x))], 
                  'simHit_t': [0 for _ in range(len(hits_x))],
                  'simHit_energy': hits_energy,
                  'simHit_clusterIndex': hits_clusterIndex,
                  'simHit_detid': hits_detid,
                  'simHit_fraction': hits_fractions,
                  'simHit_event': [self.event for _ in range(len(hits_x))]
                  }

    makeCSVFile(dictionary, self.csv_path)
    


