#ifndef SimClusterMergeWrapper_h
#define SimClusterMergeWrapper_h

#include "Tools.h"
#include "SimCluster.h"

#include <vector>
#include <cstdint>

/**
 * @class SimClusterMergeWrapper
 * @brief The SimClusterMergeWrapper class provides a wrapper for SimCluster objects.
 * 
 * The SimClusterMergeWrapper class is used to wrap a SimCluster object and provide
 * additional functionality and convenience methods for accessing and manipulating
 * the SimCluster data.
 */

class SimClusterMergeWrapper {

  public:
    SimClusterMergeWrapper(const SimCluster* sc, size_t idx) : sc_(sc),
                                                         energy_(0),
                                                         idx_(idx) {
      SimCluster* sc_tmp = const_cast<SimCluster*>(sc_);
      pos_.x = sc_tmp->positionAtBoundary().x;
      pos_.y = sc_tmp->positionAtBoundary().y;
      pos_.z = sc_tmp->positionAtBoundary().z;
      sc_tmp = nullptr;
      delete sc_tmp;
    }

    SimCluster* simCluster() const { return const_cast<SimCluster*>(sc_); }
    const Vector3D pos() { return pos_; }
    float x() { return pos_.x; }
    float y() { return pos_.y; }
    float z() { return pos_.z; }

    const float& energy() { return energy_; }
    const size_t& idx() { return idx_; }
    unsigned int getLayer() { return sc_->getLayer(); } 
    void setEnergy(float energy) { energy_ = energy; }

  private:
    const SimCluster* sc_;
    Vector3D pos_;
    float energy_;
    size_t idx_;
};

#endif
