#!/bin/sh

usage="$(basename "$0") [-h] [-r] [-g] [-m] NEVENTS NWORKERS -- script to run the workflow

where:
    -h  show this help text
    -r  recompile the project
    -g  generate the samples
    -m  run the merging algorithm

  NEVENTS  is the number of events to be generated
  NWORKERS is the number of processors to be used for the data generation
  "

recompile=false
generate_samples=false
run_merging=false
while getopts "rgmh" opt; do
  case $opt in
    r) recompile=true ;;
    g) generate_samples=true ;;
    m) run_merging=true ;;
    h) echo "$usage"
       exit
       ;;
  esac
done

print_step() {
    echo ">>> ` date` $1"
}

parse_yml() {
    python3 -c "import yaml; print(yaml.safe_load(open('data/config.yml')))"
}

print_step "Sourcing the LCG environment"
source /cvmfs/sft.cern.ch/lcg/views/LCG_105/x86_64-el9-gcc11-opt/setup.sh

export CONFIG_DIRECTORY="/ceph/abrusamolino/PFTruth/config"
export CSV_DIRECTORY="/ceph/abrusamolino/PFTruth/csv"

NEVENTS=$2
NWORKERS=$3

CURRENT_DIR=$(pwd)

# Run the data generation script
if $generate_samples ; then
    print_step "Generating the data"
    cd data
    python3 makeSamples.py --nEvents $NEVENTS --nWorkers $NWORKERS --report
fi

cd $CURRENT_DIR
# Compile the project if executable does not exist
if [ ! -f "pftruth" ] || $recompile ; then
    print_step "Cleaning up before recompiling"
    make clean -s
    print_step "Recompiling"
    make -s
fi

if $run_merging ; then
  print_step "Running the cluster merging"
  ./pftruth
fi

print_step "Done"

